function ProductManager() {

	var _productList = {};
	var _appId = "";
	var _userId = "";
	var _purchaseCallback = null;
	var _settings = {};

	this.Initialize = function(settings) {
		_settings = settings;
		_appId = _settings.appId;
		_userId = _settings.userId;

		RegisterProducts(_settings.products);
		GetProductsFromStore();
		ConfigureStore();
		
		Refresh();
	}

	this.Purchase = function(data) {
		var aliasId = data.product.product;
		
		var pid = _.find(_settings.products, function(el){return el.alias == aliasId;}).androidId;
		
		store.order(pid);
		store.when(pid).approved(function(product){
			product.verify();
		});

		store.when(pid).verified(function(product) {
			ConfirmPurchase(product);
		});
	}

	function ConfirmPurchase(product) {
		product.priceNum =  parseFloat(product.price.replace(/[^0-9\.\,]+/g, '').replace(',', '.'))
		var receipt = JSON.parse(product.transaction.receipt);

		var purchase = {
			packageName: receipt.packageName,
			orderId: product.transaction.id,
			productId: product.alias,
			productIdLong: product.id,
			sandbox: false,
			token: product.purchaseToken,
			signature: product.transaction.signature,
			transactionId: product.transaction.id,
			deviceType: 0,
			userId: _userId,
			itemPrice: product.priceNum,
			itemCurrency: product.currency,
			receipt: JSON.stringify(receipt),
			purchaseTime: receipt.purchaseTime,
			type: 'consumable'
		};
		
		window.framePostMessage('checkPurchase', purchase);
	}

	this.SuccessPurchase = function(data) {
		var product = store.get(data.product);
		if(!product || product.state !== store.APPROVED) {
			return;
		}

		product.priceNum =  parseFloat(product.price.replace(/[^0-9\.\,]+/g, '').replace(',', '.'))

		if (window.fabric && window.fabric.Answers) {
            window.fabric.Answers.sendPurchase(
                product.priceNum,
                product.currency,
                true,
                null,
                "phonegap",
                product.alias
            );
        }

		product.finish();
	}

	function RegisterProducts(products) {
		products.forEach(function(product){
			_productList[product.gameId] = product.androidId;

			store.register({
				id:		product.androidId,
				type:	store.CONSUMABLE,
				alias:	product.alias
			});
		});
	} 

	function GetProductsFromStore() {
		var products = {};
		store.ready(function(){
			_.each(store.products, function(prod){
				if(!prod.state || !prod.state == store.INVALID) {
					return;
				}
				products[prod.alias] = {
					itemPrice: 0,
					price: prod.price,
					price_currency_code: prod.currency,
				};
				
			});


			ApplyGettedProducts();
			window.framePostMessage('applyAndroidProducts', products);

		});
	}	

	function ApplyGettedProducts(){
		_.each(store.products, function(product){
			if(product.state == store.APPROVED) {
				ConfirmPurchase(product);
			}
		});
	}

	function ConfigureStore() {
		store.validator = function(product, callback) {
			callback(true, {});
		};
	}
	
	function Refresh() {
		store.refresh();
	}

}